@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # From https://itshouldbeuseful.wordpress.com/2010/11/10/find-your-slowest-running-cucumber-features/
 
 scenario_times = {}
@@ -16,6 +18,6 @@ at_exit do
   slowest_times = sorted_times.first(20)
   puts "------------- Top #{slowest_times.size} slowest scenarios -------------"
   slowest_times.each do |key, value|
-    puts format("%.2f  %s", value, key)
+    puts format('%.2f  %s', value, key)
   end
 end
