@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'pathname'
 
 # Aruba
@@ -57,9 +59,8 @@ module Aruba
     # Get path
     def to_pathname
       current_path = @obj.inject do |path, element|
-        if element.start_with? '~'
-          element
-        elsif Aruba.platform.absolute_path? element
+        if element.start_with?('~') ||
+           Aruba.platform.absolute_path?(element)
           element
         else
           File.join(path, element)
