@@ -4,16 +4,12 @@ require 'rspec/core'
 require 'aruba/api'
 
 RSpec.configure do |config|
-  config.filter_run focus: true
-
-  config.run_all_when_everything_filtered = true
+  config.filter_run_when_matching :focus
 
   config.example_status_persistence_file_path = 'tmp/rspec-examples.txt'
   config.profile_examples = 10
 
-  config.expect_with :rspec do |c|
-    c.syntax = :expect
-  end
+  config.expect_with :rspec
 
   config.include Aruba::Api
   config.before { setup_aruba }
